@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -35,9 +35,7 @@
 void
 sebie_update_view(struct sebie_s *sebie,
                   GtkDrawingArea *area,
-                  cairo_t *cr,
-                  int width,
-                  int height)
+                  cairo_t *cr)
 #else
 void
 sebie_update_view(struct sebie_s *sebie)
@@ -73,13 +71,7 @@ sebie_update_view(struct sebie_s *sebie)
   }
 
   if (sebie->dirty_tags & SEBIE_UPDATE_IMAGE_GAMMA) {
-#if GTK_CHECK_VERSION(4,0,0)
     gtk_spin_button_set_value (GTK_SPIN_BUTTON(sebie->view.entry_selection_gamma), sebie->model.image_gamma);
-#else
-    gchar buf[6];
-    snprintf(buf, 6, "%1.1f", sebie->model.image_gamma);
-    gtk_entry_set_text(GTK_ENTRY(sebie->view.entry_selection_gamma), buf);
-#endif
   }
 
 #if GTK_CHECK_VERSION(4,0,0)
@@ -112,8 +104,13 @@ sebie_update_view(struct sebie_s *sebie)
     // SEBIE_UPDATE_SELECTION_RECT could be optimized to (SEBIE_UPDATE_SELECTION_RECT && rect extens scaled_pixbuf area)
     if ((sebie->dirty_tags & SEBIE_UPDATE_SCALED_PIXBUF) || (sebie->dirty_tags & SEBIE_UPDATE_SELECTION_RECT)) {
 #if GTK_CHECK_VERSION(3,0,0)
+#if GTK_CHECK_VERSION(4,12,0)
+      int drawingarea1_width = gtk_widget_get_width(sebie->view.drawingarea1);
+      int drawingarea2_height = gtk_widget_get_height(sebie->view.drawingarea1);
+#else
       int drawingarea1_width = gtk_widget_get_allocated_width(sebie->view.drawingarea1);
       int drawingarea2_height = gtk_widget_get_allocated_height(sebie->view.drawingarea1);
+#endif
       cairo_set_source_rgb(cr, 0.878, 0.878, 0.878);
       cairo_rectangle (cr, 0, 0, drawingarea1_width, drawingarea2_height);
       cairo_fill(cr);
@@ -234,8 +231,12 @@ sebie_update_view(struct sebie_s *sebie)
   }
 
   if (sebie->dirty_tags & SEBIE_UPDATE_STATUS_BAR) {
+#if GTK_CHECK_VERSION(4,10,0)
+    gtk_label_set_text(GTK_LABEL(sebie->view.statusbar1), sebie->model.statusbar_text);
+#else
     gtk_statusbar_pop(GTK_STATUSBAR(sebie->view.statusbar1), sebie->view.statusbar1_context_id);
     gtk_statusbar_push(GTK_STATUSBAR(sebie->view.statusbar1), sebie->view.statusbar1_context_id, sebie->model.statusbar_text);
+#endif
   }
 
   sebie->dirty_tags = 0;
@@ -246,6 +247,11 @@ sebie_update_view(struct sebie_s *sebie)
 void
 sebie_error_popup(struct sebie_s *sebie, const gchar *error_str)
 {
+#if GTK_CHECK_VERSION(4,10,0)
+  GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error_str);
+  gtk_alert_dialog_show (dialog, GTK_WINDOW(sebie->view.window1));
+  g_object_unref (dialog);
+#else
   GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW(sebie->view.window1),
                                               GTK_DIALOG_DESTROY_WITH_PARENT,
                                               GTK_MESSAGE_ERROR,
@@ -264,22 +270,33 @@ sebie_error_popup(struct sebie_s *sebie, const gchar *error_str)
   gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
 #endif
+#endif
 }
 
 
-void
+static void
 sebie_file_list_clear(struct sebie_s *sebie)
 {
+#if GTK_CHECK_VERSION(4,10,0)
+    guint n = g_list_model_get_n_items (G_LIST_MODEL(sebie->model.file_list));
+    for(; n > 0; n--) {
+        gtk_string_list_remove (sebie->model.file_list, n - 1);
+    }
+#else
   if (sebie->model.file_list == NULL) {
     return;
   }
   gtk_list_store_clear(sebie->model.file_list);
+#endif
 }
 
 
-void
+static void
 sebie_file_list_add(struct sebie_s *sebie, const gchar *filename)
 {
+#if GTK_CHECK_VERSION(4,10,0)
+    gtk_string_list_append(sebie->model.file_list, filename);
+#else
   if (sebie->model.file_list == NULL) {
     sebie->model.file_list = gtk_list_store_new(1, G_TYPE_STRING);
     gtk_tree_view_set_model(GTK_TREE_VIEW(sebie->view.treeview_file_list), GTK_TREE_MODEL(sebie->model.file_list));
@@ -287,6 +304,7 @@ sebie_file_list_add(struct sebie_s *sebie, const gchar *filename)
   GtkTreeIter iter;
   gtk_list_store_append(sebie->model.file_list, &iter);
   gtk_list_store_set(sebie->model.file_list, &iter, 0, filename, -1);
+#endif
 }
 
 void
@@ -382,7 +400,7 @@ sebie_update_file_list(struct sebie_s *sebie)
 
 
 void
-rotate_scaled(struct sebie_s *sebie, int direction)
+rotate_scaled(struct sebie_s *sebie, sebie_rotation direction)
 {
   if (direction == SEBIE_ROTATE_090 ||
       direction == SEBIE_ROTATE_270 ) {
@@ -398,7 +416,7 @@ rotate_scaled(struct sebie_s *sebie, int direction)
     sebie->dirty_tags |= SEBIE_UPDATE_SCALED_PIXBUF;
     sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
 #if GTK_CHECK_VERSION(4,0,0)
-    sebie_update_view(sebie, NULL, NULL, 0, 0);
+    sebie_update_view(sebie, NULL, NULL);
 #else
     sebie_update_view(sebie);
 #endif
@@ -430,7 +448,7 @@ apply_color_corrections(struct sebie_s *sebie)
     sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
   }
 #if GTK_CHECK_VERSION(4,0,0)
-  sebie_update_view(sebie, NULL, NULL, 0, 0);
+  sebie_update_view(sebie, NULL, NULL);
 #else
   sebie_update_view(sebie);
 #endif
@@ -462,8 +480,41 @@ save_sebie_config(struct sebie_s *sebie)
   }
 }
 
+#define SEBIE_N_MATCH  2
 
 void
+sebie_set_selected_image(struct sebie_s *sebie, const char *filename)
+{
+  sebie_set_string(&sebie->model.input_file_name, filename);
+  load_pixbuf(sebie);
+  if (sebie->model.regex_status) {
+    regmatch_t matchptr[SEBIE_N_MATCH];
+    if (regexec(&sebie->model.regex, sebie->model.input_file_name, SEBIE_N_MATCH, matchptr, 0) == 0) {
+      char buf_regex[SEBIE_N_MATCH][256];
+      int i;
+      for (i = 0; i < SEBIE_N_MATCH; i++) {
+        strncpy(buf_regex[i],sebie->model.input_file_name +  matchptr[i].rm_so, matchptr[i].rm_eo - matchptr[i].rm_so);
+        buf_regex[i][matchptr[i].rm_eo - matchptr[i].rm_so] = '\0';
+        sebie_debug("buf_regex[%d] = %s\n", i, buf_regex[i]);
+      }
+      char buf[256];
+      snprintf(buf, 256, sebie->model.output_format, buf_regex[1]);
+      sebie_set_string(&sebie->model.output_file_name, buf);
+      sebie->dirty_tags |= SEBIE_UPDATE_OUTPUT_FILE_NAME;
+#if GTK_CHECK_VERSION(4,0,0)
+      sebie_update_view(sebie, NULL, NULL);
+#else
+      sebie_update_view(sebie);
+#endif
+    }
+  } else {
+      sebie_debug("sebie->model.regex_status invalid");
+  }
+}
+
+#undef SEBIE_N_MATCH
+
+static void
 init_sebie_model(struct sebie_s *sebie)
 {
   char *homedir;
@@ -505,7 +556,12 @@ init_sebie_model(struct sebie_s *sebie)
   sebie->dirty_tags |= SEBIE_UPDATE_INPUT_REGEX;
   sebie->dirty_tags |= SEBIE_UPDATE_OUTPUT_FORMAT;
 
+#if GTK_CHECK_VERSION(4,10,0)
+  sebie->model.file_list = gtk_string_list_new (NULL);
+  sebie->model.file_list_selection = gtk_single_selection_new (G_LIST_MODEL (sebie->model.file_list));
+#else
   sebie->model.file_list = gtk_list_store_new(1, G_TYPE_STRING);
+#endif
 
   sebie->model.selection_fac = sebie->model.selection_fac_width / sebie->model.selection_fac_height;
 
@@ -516,13 +572,13 @@ init_sebie_model(struct sebie_s *sebie)
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC_H;
   sebie->dirty_tags |= SEBIE_UPDATE_IMAGE_GAMMA;
 
-  sebie->model.statusbar_text = strdup("   SeBIE-" PACKAGE_VERSION " (c) 2002-2022 by Peter.Seiderer@ciselant.de");
+  sebie->model.statusbar_text = strdup("   SeBIE-" PACKAGE_VERSION " (c) 2002-2023 by Peter.Seiderer@ciselant.de");
   sebie->dirty_tags |= SEBIE_UPDATE_STATUS_BAR;
 
   sebie_regcomp(sebie);
 }
 
-void
+static void
 deinit_sebie_model(struct sebie_s *sebie)
 {
     if (sebie->model.input_path != NULL) {
@@ -563,7 +619,7 @@ deinit_sebie_model(struct sebie_s *sebie)
     g_free(sebie->config_file);
 }
 
-int main(int argc, char *argv[])
+int main(G_GNUC_UNUSED int argc, G_GNUC_UNUSED char *argv[])
 {
   GtkWidget *window1;
   struct sebie_s *sebie;
@@ -585,12 +641,16 @@ int main(int argc, char *argv[])
   window1 = init_sebie_view(sebie);
 
 #if GTK_CHECK_VERSION(4,0,0)
-  sebie_update_view(sebie, NULL, NULL, 0, 0);
+  sebie_update_view(sebie, NULL, NULL);
 #else
   sebie_update_view(sebie);
 #endif
 
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (window1, TRUE);
+#else
   gtk_widget_show (window1);
+#endif
 
 #if GTK_CHECK_VERSION(4,0,0)
   while (g_list_model_get_n_items (gtk_window_get_toplevels ()) > 0) {
