@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -129,11 +129,19 @@ typedef struct sebie_view_s {
   GtkWidget *entry_output_format;
   GtkWidget *label_output_file;
   GtkWidget *entry_output_file;
+#if GTK_CHECK_VERSION(4,10,0)
+  GtkWidget *label_file_list;
+#endif
   GtkWidget *scrolledwindow1;
+#if GTK_CHECK_VERSION(4,10,0)
+  GtkListItemFactory *treeview_file_list_factory;
+#endif
   GtkWidget *treeview_file_list;
   GtkWidget *drawingarea1;
   GtkWidget *statusbar1;
+#if !GTK_CHECK_VERSION(4,10,0)
   guint statusbar1_context_id;
+#endif
 } sebie_view;
 
 typedef struct sebie_model_s {
@@ -145,7 +153,12 @@ typedef struct sebie_model_s {
   char *output_file_name;
   regex_t regex;
   int regex_status;
+#if GTK_CHECK_VERSION(4,10,0)
+  GtkStringList *file_list;
+  GtkSingleSelection *file_list_selection;
+#else
   GtkListStore *file_list;
+#endif
   /* orig image */
   GdkPixbuf *image_pixbuf;
   gint image_width;
@@ -186,26 +199,25 @@ typedef struct sebie_model_s {
 typedef struct sebie_s {
   sebie_view  view;
   sebie_model model;
-  sebie_dirty_tag dirty_tags;
-  sebie_model_tag model_tags;
+  guint dirty_tags;
+  guint model_tags;
   char *config_file;
 } struct_sebie;
 
 #if GTK_CHECK_VERSION(4,0,0)
 void sebie_update_view(struct sebie_s *sebie,
                        GtkDrawingArea *area,
-                       cairo_t *cr,
-                       int width,
-                       int height);
+                       cairo_t *cr);
 #else
 void sebie_update_view(struct sebie_s *sebie);
 #endif
 void sebie_error_popup(struct sebie_s *sebie, const gchar *error_str);
 void load_pixbuf (struct sebie_s *sebie);
 void sebie_update_file_list(struct sebie_s *sebie);
-void rotate_scaled(struct sebie_s *sebie, int direction);
+void rotate_scaled(struct sebie_s *sebie, sebie_rotation direction);
 void apply_color_corrections(struct sebie_s *sebie);
 void save_sebie_config(struct sebie_s *sebie);
+void sebie_set_selected_image(struct sebie_s *sebie, const char *filename);
 
 /*
  * Standard gettext macros.
