@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -29,6 +29,26 @@
 #define SEBIE_CATCH_PIXEL_COUNT  15
 
 
+#if GTK_CHECK_VERSION(4,10,0)
+void
+on_file_list_single_selection_changed (G_GNUC_UNUSED GtkSingleSelection *selection,
+                                       G_GNUC_UNUSED guint position,
+                                       G_GNUC_UNUSED guint n_items,
+                                       gpointer user_data)
+{
+  struct sebie_s *sebie = (struct sebie_s *)user_data;
+
+  guint n = g_list_model_get_n_items (G_LIST_MODEL(sebie->model.file_list));
+  for(; n > 0; n--) {
+      gboolean selected = gtk_selection_model_is_selected (GTK_SELECTION_MODEL(sebie->model.file_list_selection), n - 1);
+      if (selected) {
+          const char* filename = gtk_string_list_get_string (sebie->model.file_list, n - 1);
+          sebie_set_selected_image(sebie, filename);
+          break;
+      }
+  }
+}
+#else
 void
 on_treeview_file_list_changed(GtkTreeSelection *selection,
                               gpointer user_data)
@@ -39,35 +59,11 @@ on_treeview_file_list_changed(GtkTreeSelection *selection,
     gchar *filename;
     if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
         gtk_tree_model_get(model, &iter, 0, &filename, -1);
-        sebie_set_string(&sebie->model.input_file_name, filename);
+        sebie_set_selected_image(sebie, filename);
         g_free(filename);
-        load_pixbuf(sebie);
-        if (sebie->model.regex_status) {
-            int nmatch = 2;
-            regmatch_t matchptr[nmatch];
-            if (regexec(&sebie->model.regex, sebie->model.input_file_name, nmatch, matchptr, 0) == 0) {
-                char buf_regex[nmatch][256];
-                int i;
-                for (i = 0; i < nmatch; i++) {
-                    strncpy(buf_regex[i],sebie->model.input_file_name +  matchptr[i].rm_so, matchptr[i].rm_eo - matchptr[i].rm_so);
-                    buf_regex[i][matchptr[i].rm_eo - matchptr[i].rm_so] = '\0';
-                    sebie_debug("buf_regex[%d] = %s\n", i, buf_regex[i]);
-                }
-              char buf[256];
-              snprintf(buf, 256, sebie->model.output_format, buf_regex[1]);
-              sebie_set_string(&sebie->model.output_file_name, buf);
-              sebie->dirty_tags |= SEBIE_UPDATE_OUTPUT_FILE_NAME;
-#if GTK_CHECK_VERSION(4,0,0)
-              sebie_update_view(sebie, NULL, NULL, 0, 0);
-#else
-              sebie_update_view(sebie);
-#endif
-          }
-      } else {
-          sebie_debug("sebie->model.regex_status invalid");
-      }
   }
 }
+#endif
 
 void
 on_entry_input_path_changed (GtkEditable *editable,
@@ -123,9 +119,9 @@ on_entry_output_format_changed (GtkEditable *editable,
 
 
 gint
-window1_delete_event (GtkWidget *widget,
-              GdkEvent  *event,
-              gpointer   data)
+window1_delete_event (G_GNUC_UNUSED GtkWidget *widget,
+                      G_GNUC_UNUSED GdkEvent *event,
+                      G_GNUC_UNUSED gpointer data)
 {
     sebie_debug("window1_delete_event\n");
     return FALSE;
@@ -133,8 +129,8 @@ window1_delete_event (GtkWidget *widget,
 
 
 void
-window1_destroy (GtkWidget *widget,
-         gpointer   data)
+window1_destroy (G_GNUC_UNUSED GtkWidget *widget,
+                 G_GNUC_UNUSED gpointer data)
 {
     sebie_debug("window1_destroy\n");
 
@@ -146,7 +142,7 @@ window1_destroy (GtkWidget *widget,
 
 #if GTK_CHECK_VERSION(4,0,0)
 void
-drawingarea1_resize (GtkWidget *widget,
+drawingarea1_resize (G_GNUC_UNUSED GtkWidget *widget,
                      gint width,
                      gint height,
                      gpointer user_data)
@@ -168,9 +164,9 @@ drawingarea1_resize (GtkWidget *widget,
 }
 #else
 void
-drawingarea1_size_allocate (GtkWidget *widget,
-                GtkAllocation *allocation,
-                gpointer   user_data)
+drawingarea1_size_allocate (G_GNUC_UNUSED GtkWidget *widget,
+                            GtkAllocation *allocation,
+                            gpointer user_data)
 {
     struct sebie_s *sebie = (struct sebie_s *)user_data;
     gint window1_width;
@@ -195,8 +191,12 @@ drawingarea1_size_allocate (GtkWidget *widget,
 
 
 void
-on_button_quit_clicked (GtkButton *button,
-            gpointer  user_data)
+on_button_quit_clicked (G_GNUC_UNUSED GtkButton *button,
+#if GTK_CHECK_VERSION(4,0,0)
+                        gpointer user_data)
+#else
+                        G_GNUC_UNUSED gpointer user_data)
+#endif
 {
 #if GTK_CHECK_VERSION(4,0,0)
   struct sebie_s *sebie = (struct sebie_s *)user_data;
@@ -212,8 +212,8 @@ on_button_quit_clicked (GtkButton *button,
 
 
 void
-on_button_save_clicked (GtkButton *button,
-            gpointer  user_data)
+on_button_save_clicked (G_GNUC_UNUSED GtkButton *button,
+                        gpointer user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
 
@@ -322,8 +322,8 @@ on_button_save_clicked (GtkButton *button,
 
 
 void
-on_button_rotate_left_clicked (GtkButton *button,
-                   gpointer  user_data)
+on_button_rotate_left_clicked (G_GNUC_UNUSED GtkButton *button,
+                               gpointer user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
 
@@ -337,8 +337,8 @@ on_button_rotate_left_clicked (GtkButton *button,
 }
 
 void
-on_button_rotate_right_clicked (GtkButton *button,
-                gpointer  user_data)
+on_button_rotate_right_clicked (G_GNUC_UNUSED GtkButton *button,
+                                gpointer user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
 
@@ -378,7 +378,7 @@ on_entry_selection_fac_width_changed (GtkEditable *editable,
         sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC;
     }
 #if GTK_CHECK_VERSION(4,0,0)
-    sebie_update_view(sebie, NULL, NULL, 0, 0);
+    sebie_update_view(sebie, NULL, NULL);
 #else
     sebie_update_view(sebie);
 #endif
@@ -412,7 +412,7 @@ on_entry_selection_fac_height_changed (GtkEditable *editable,
         sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC;
     }
 #if GTK_CHECK_VERSION(4,0,0)
-    sebie_update_view(sebie, NULL, NULL, 0, 0);
+    sebie_update_view(sebie, NULL, NULL);
 #else
     sebie_update_view(sebie);
 #endif
@@ -420,8 +420,8 @@ on_entry_selection_fac_height_changed (GtkEditable *editable,
 }
 
 void
-on_button_fac_swap (GtkButton *button,
-            gpointer  user_data)
+on_button_fac_swap (G_GNUC_UNUSED GtkButton *button,
+                    gpointer user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
   gint tmp = sebie->model.selection_fac_width;
@@ -432,7 +432,7 @@ on_button_fac_swap (GtkButton *button,
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC_W;
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC_H;
 #if GTK_CHECK_VERSION(4,0,0)
-  sebie_update_view(sebie, NULL, NULL, 0, 0);
+  sebie_update_view(sebie, NULL, NULL);
 #else
   sebie_update_view(sebie);
 #endif
@@ -458,7 +458,7 @@ on_entry_selection_gamma_changed (GtkEditable *editable,
     sebie_debug("new_gamma %lf out of range\n", new_gamma);
     return;
   }
-  if (new_gamma == sebie->model.image_gamma) {
+  if (sebie_compare_eq_double(new_gamma, sebie->model.image_gamma, 1.0e-5)) {
     sebie_debug("new_gamma %lf == old_gamma\n", new_gamma);
     return;
   }
@@ -509,20 +509,20 @@ on_button_grayscale_clicked(GtkToggleButton *button,
 void
 drawingarea1_draw_function(GtkDrawingArea *area,
                            cairo_t *cr,
-                           int width,
-                           int height,
+                           G_GNUC_UNUSED int width,
+                           G_GNUC_UNUSED int height,
                            gpointer user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
   sebie->dirty_tags |= SEBIE_UPDATE_SCALED_PIXBUF;
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
-  sebie_update_view(sebie, area, cr, width, height);
+  sebie_update_view(sebie, area, cr);
 }
 #else
 gboolean
-on_drawingarea1_expose_event (GtkWidget       *widget,
-                  GdkEventExpose  *event,
-                  gpointer         user_data)
+on_drawingarea1_expose_event (G_GNUC_UNUSED GtkWidget *widget,
+                              G_GNUC_UNUSED GdkEventExpose *event,
+                              gpointer user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
 #if GTK_CHECK_VERSION(3,0,0)
@@ -627,7 +627,7 @@ in_lower_left_corner(gint x, gint y, struct sebie_s *sebie)
 
 #if GTK_CHECK_VERSION(4,0,0)
 void
-on_drawingarea1_drag_begin(GtkGestureDrag *gesture,
+on_drawingarea1_drag_begin(G_GNUC_UNUSED GtkGestureDrag *gesture,
                            double x,
                            double y,
                            gpointer user_data)
@@ -668,7 +668,7 @@ on_drawingarea1_drag_begin(GtkGestureDrag *gesture,
     }
 
     sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
-    sebie_update_view(sebie, NULL, NULL, 0, 0);
+    sebie_update_view(sebie, NULL, NULL);
 }
 
 
@@ -798,17 +798,17 @@ on_drawingarea1_drag_update(GtkGestureDrag *gesture,
     }
 
     sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
-    sebie_update_view(sebie, NULL, NULL, 0, 0);
+    sebie_update_view(sebie, NULL, NULL);
 
     drawingarea1_update_cursor(x, y, sebie);
 }
 
 
 void
-on_drawingarea1_drag_end(GtkGestureDrag *gesture,
+on_drawingarea1_drag_end(G_GNUC_UNUSED GtkGestureDrag *gesture,
                          double x,
                          double y,
-                         gpointer user_data)
+                         G_GNUC_UNUSED gpointer user_data)
 {
     struct sebie_s *sebie = (struct sebie_s *)user_data;
 
@@ -819,10 +819,10 @@ on_drawingarea1_drag_end(GtkGestureDrag *gesture,
 
 
 void
-on_drawingarea1_motion(GtkEventControllerMotion *controller,
+on_drawingarea1_motion(G_GNUC_UNUSED GtkEventControllerMotion *controller,
                        double x,
                        double y,
-                       gpointer user_data)
+                       G_GNUC_UNUSED gpointer user_data)
 {
     struct sebie_s *sebie = (struct sebie_s *)user_data;
 
@@ -831,13 +831,13 @@ on_drawingarea1_motion(GtkEventControllerMotion *controller,
     drawingarea1_update_cursor(x, y, sebie);
 
     sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
-    sebie_update_view(sebie, NULL, NULL, 0, 0);
+    sebie_update_view(sebie, NULL, NULL);
 }
 #else
 gboolean
-on_drawingarea1_button_press_event (GtkWidget       *widget,
-                    GdkEventButton  *event,
-                    gpointer         user_data)
+on_drawingarea1_button_press_event (G_GNUC_UNUSED GtkWidget *widget,
+                                    GdkEventButton *event,
+                                    gpointer user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
 
@@ -885,9 +885,9 @@ on_drawingarea1_button_press_event (GtkWidget       *widget,
 
 #if !GTK_CHECK_VERSION(4,0,0)
 gboolean
-on_drawingarea1_motion_notify_event (GtkWidget       *widget,
-                     GdkEventMotion  *event,
-                     gpointer         user_data)
+on_drawingarea1_motion_notify_event (G_GNUC_UNUSED GtkWidget *widget,
+                                     GdkEventMotion *event,
+                                     gpointer user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
 
@@ -1056,13 +1056,15 @@ on_drawingarea1_motion_notify_event (GtkWidget       *widget,
 #endif
 
 
+#if !GTK_CHECK_VERSION(4,10,0)
 #if GTK_CHECK_VERSION(4,0,0)
 void
 on_error_dialog_response (GtkDialog *dialog,
                           int response,
-                          gpointer user_data)
+                          G_GNUC_UNUSED gpointer user_data)
 {
     sebie_debug("on_error_dialog_response() - response: %d\n", response);
     gtk_window_destroy (GTK_WINDOW(dialog));
 }
 #endif
+#endif
