@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -23,9 +23,18 @@
 
 #include <gtk/gtk.h>
 
+#if GTK_CHECK_VERSION(4,10,0)
+void
+on_file_list_single_selection_changed (GtkSingleSelection *selection,
+                                       guint position,
+                                       guint n_items,
+                                       gpointer user_data);
+#else
 void
 on_treeview_file_list_changed (GtkTreeSelection *selection,
                                gpointer user_data);
+#endif
+
 
 void
 on_entry_input_path_changed (GtkEditable *editable,
@@ -154,11 +163,13 @@ on_drawingarea1_motion_notify_event (GtkWidget *widget,
                                      gpointer user_data);
 #endif
 
+#if !GTK_CHECK_VERSION(4,10,0)
 #if GTK_CHECK_VERSION(4,0,0)
 void
 on_error_dialog_response (GtkDialog *dialog,
                           int response,
                           gpointer user_data);
 #endif
+#endif
 
 #endif /* _SEBIE_CALLBACKS_H_ */
