@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2003-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -57,8 +57,9 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
     case CONFIG_STRING:
       *spec[i].storage.string = g_strdup(spec[i].defvalue.string);
       break;
+    case CONFIG_END:
     default:
-      sebie_error("Error: unknown config type %d.\n", spec[i].type);
+      sebie_error("Error: unknown config type %u.\n", spec[i].type);
       return 1;
     }
     i++;
@@ -126,8 +127,9 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
             }
             *spec[i].storage.string = g_strdup(value);
           break;
+          case CONFIG_END:
           default:
-            sebie_error("Error: unknown config type %d.\n", spec[i].type);
+            sebie_error("Error: unknown config type %u.\n", spec[i].type);
             fclose(file);
             return 1;
         }
@@ -165,9 +167,10 @@ sebie_write_config(const char *path, sebie_config_spec *spec)
     case CONFIG_STRING:
       fprintf(file, "%s=%s\n", spec[i].name, *spec[i].storage.string);
       break;
+    case CONFIG_END:
     default:
       /* write out error and ignore */
-      sebie_error("Error: unknown config type %d.\n", spec[i].type);
+      sebie_error("Error: unknown config type %u.\n", spec[i].type);
     }
     i++;
   }
