@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2003-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -29,7 +29,7 @@ typedef enum sebie_config_type_e {
 } sebie_config_type;
 
 typedef struct sebie_config_spec_s {
-  char *name;
+  const char *name;
   sebie_config_type type;
   union storage_u {
     int    *integer;
@@ -39,7 +39,7 @@ typedef struct sebie_config_spec_s {
   union defvalue_u {
     int    integer;
     double doublev;
-    char   *string;
+    const char *string;
   } defvalue;
 } sebie_config_spec;
 
