@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -19,12 +19,13 @@
  *
  */
 #include "sebie_gtk_helpers.h"
+#include "sebie_helpers.h"
 
 #include <math.h>
 
 
 GdkPixbuf *
-rotate_pixbuf(GdkPixbuf *pixbuf, int rotation)
+rotate_pixbuf(GdkPixbuf *pixbuf, sebie_rotation rotation)
 {
   gint new_width;
   gint new_height;
@@ -85,7 +86,7 @@ rotate_pixbuf(GdkPixbuf *pixbuf, int rotation)
 GdkPixbuf *
 pixbuf_color_corrections(GdkPixbuf *pixbuf, double gamma, int grayscale)
 {
-  if (gamma == 1.0 && grayscale == 0) {
+  if (sebie_compare_eq_double(gamma, 1.0, 1.0e-05) && (grayscale == 0)) {
     return gdk_pixbuf_copy(pixbuf);
   } else {
     GdkPixbuf *corrected = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pixbuf),
@@ -105,7 +106,7 @@ pixbuf_color_corrections(GdkPixbuf *pixbuf, double gamma, int grayscale)
     int i, j;
     guchar *gamma_lut;
 
-    gamma_lut = g_malloc0(256);
+    gamma_lut = (guchar*)g_malloc0(256);
     // compute gamma_lut
     for (i = 0; i < 256; i++) {
       double luv = pow ((double) i / 256.0, 1.0 / gamma) * 256.0;
