@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -24,7 +24,7 @@
 #include "sebie.h"
 
 GdkPixbuf *
-rotate_pixbuf(GdkPixbuf *pixbuf, int rotation);
+rotate_pixbuf(GdkPixbuf *pixbuf, sebie_rotation rotation);
 
 GdkPixbuf *
 pixbuf_color_corrections(GdkPixbuf *pixbuf, double gamma, int grayscale);
