@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -29,12 +29,15 @@ void
 sebie_set_string(gchar **old_text, const gchar *new_text);
 
 void
-sebie_error(const char *format, ...);
+sebie_error(const char *format, ...) __attribute__((format(printf,1,2)));
 
 void
-sebie_debug(const char *format, ...);
+sebie_debug(const char *format, ...) __attribute__((format(printf,1,2)));
 
 void
 sebie_regcomp(struct sebie_s *sebie);
 
+gboolean
+sebie_compare_eq_double(double d1, double d2, double epsilon);
+
 #endif /* _SEBIE_HELPERS_H_ */
