@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -31,6 +31,29 @@
   g_object_set_data (G_OBJECT (component), name, widget)
 
 
+#if GTK_CHECK_VERSION(4,10,0)
+static void
+file_list_setup_cb (G_GNUC_UNUSED GtkSignalListItemFactory *self,
+                    GtkListItem *listitem,
+                    G_GNUC_UNUSED gpointer user_data)
+{
+  GtkWidget *lb = gtk_label_new (NULL);
+  gtk_list_item_set_child (listitem, lb);
+}
+
+
+static void
+file_list_bind_cb (G_GNUC_UNUSED GtkSignalListItemFactory *self,
+                   GtkListItem *listitem,
+                   G_GNUC_UNUSED gpointer user_data)
+{
+  GtkWidget *lb = gtk_list_item_get_child (listitem);
+  GtkStringObject *strobj = GTK_STRING_OBJECT (gtk_list_item_get_item (listitem));
+  gtk_label_set_text (GTK_LABEL (lb), gtk_string_object_get_string (strobj));
+}
+#endif
+
+
 GtkWidget *
 init_sebie_view(struct sebie_s *sebie)
 {
@@ -44,7 +67,7 @@ init_sebie_view(struct sebie_s *sebie)
 #else
   sebie->view.window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 #endif
-  gchar * window1_title = "SeBIE " PACKAGE_VERSION ;
+  const gchar * window1_title = "SeBIE " PACKAGE_VERSION ;
   gtk_widget_set_name (sebie->view.window1, window1_title);
   gtk_window_set_title (GTK_WINDOW (sebie->view.window1), window1_title);
 
@@ -52,7 +75,11 @@ init_sebie_view(struct sebie_s *sebie)
   sebie->view.grid1 = gtk_grid_new ();
   gtk_grid_set_column_homogeneous (GTK_GRID(sebie->view.grid1), FALSE);
   gtk_grid_set_row_homogeneous (GTK_GRID(sebie->view.grid1), FALSE);
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.grid1, TRUE);
+#else
   gtk_widget_show (sebie->view.grid1);
+#endif
 #else
   sebie->view.vbox1 = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (sebie->view.vbox1);
@@ -73,7 +100,11 @@ init_sebie_view(struct sebie_s *sebie)
 #else
   sebie->view.toolbar1 = gtk_toolbar_new ();
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.toolbar1, TRUE);
+#else
   gtk_widget_show (sebie->view.toolbar1);
+#endif
 #if GTK_CHECK_VERSION(3,0,0)
   gtk_grid_attach (GTK_GRID (sebie->view.grid1), sebie->view.toolbar1, 0, 0, 2, 1);
   gtk_widget_set_hexpand(sebie->view.toolbar1, TRUE);
@@ -97,7 +128,11 @@ init_sebie_view(struct sebie_s *sebie)
                                                         NULL, NULL, NULL);
   gtk_label_set_use_underline (GTK_LABEL (((GtkToolbarChild*) (g_list_last (GTK_TOOLBAR (sebie->view.toolbar1)->children)->data))->label), TRUE);
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (GTK_WIDGET(sebie->view.button_quit), TRUE);
+#else
   gtk_widget_show (GTK_WIDGET(sebie->view.button_quit));
+#endif
 
 #if GTK_CHECK_VERSION(4,0,0)
   sebie->view.button_save = gtk_button_new_with_label (_("Save"));
@@ -114,7 +149,11 @@ init_sebie_view(struct sebie_s *sebie)
                                 NULL, NULL, NULL);
   gtk_label_set_use_underline (GTK_LABEL (((GtkToolbarChild*) (g_list_last (GTK_TOOLBAR (sebie->view.toolbar1)->children)->data))->label), TRUE);
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (GTK_WIDGET(sebie->view.button_save), TRUE);
+#else
   gtk_widget_show (GTK_WIDGET(sebie->view.button_save));
+#endif
 
 #if GTK_CHECK_VERSION(4,0,0)
   sebie->view.button_rotate_left = gtk_button_new_with_label (_("<- Rotate"));
@@ -131,7 +170,11 @@ init_sebie_view(struct sebie_s *sebie)
                                 NULL, NULL, NULL);
   gtk_label_set_use_underline (GTK_LABEL (((GtkToolbarChild*) (g_list_last (GTK_TOOLBAR (sebie->view.toolbar1)->children)->data))->label), TRUE);
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (GTK_WIDGET(sebie->view.button_rotate_left), TRUE);
+#else
   gtk_widget_show (GTK_WIDGET(sebie->view.button_rotate_left));
+#endif
 
 #if GTK_CHECK_VERSION(4,0,0)
   sebie->view.button_rotate_right = gtk_button_new_with_label (_("Rotate ->"));
@@ -148,10 +191,18 @@ init_sebie_view(struct sebie_s *sebie)
                                 NULL, NULL, NULL);
   gtk_label_set_use_underline (GTK_LABEL (((GtkToolbarChild*) (g_list_last (GTK_TOOLBAR (sebie->view.toolbar1)->children)->data))->label), TRUE);
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (GTK_WIDGET(sebie->view.button_rotate_right), TRUE);
+#else
   gtk_widget_show (GTK_WIDGET(sebie->view.button_rotate_right));
+#endif
 
   sebie->view.label_selection_fac_width = gtk_label_new (_(" w:"));
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.label_selection_fac_width, TRUE);
+#else
   gtk_widget_show (sebie->view.label_selection_fac_width);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.toolbar1), sebie->view.label_selection_fac_width);
 #elif GTK_CHECK_VERSION(3,0,0)
@@ -165,7 +216,11 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_fac_width), GTK_JUSTIFY_LEFT);
 
   sebie->view.entry_selection_fac_width = gtk_entry_new ();
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.entry_selection_fac_width, TRUE);
+#else
   gtk_widget_show (sebie->view.entry_selection_fac_width);
+#endif
 
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.toolbar1), sebie->view.entry_selection_fac_width);
@@ -180,7 +235,11 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_widget_set_size_request (sebie->view.entry_selection_fac_width, 50, 20);
   gtk_entry_set_max_length (GTK_ENTRY (sebie->view.entry_selection_fac_width), 5);
   sebie->view.label_selection_fac_height = gtk_label_new (_(" h:"));
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.label_selection_fac_height, TRUE);
+#else
   gtk_widget_show (sebie->view.label_selection_fac_height);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.toolbar1), sebie->view.label_selection_fac_height);
 #elif GTK_CHECK_VERSION(3,0,0)
@@ -194,7 +253,11 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_fac_height), GTK_JUSTIFY_LEFT);
 
   sebie->view.entry_selection_fac_height = gtk_entry_new ();
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.entry_selection_fac_height, TRUE);
+#else
   gtk_widget_show (sebie->view.entry_selection_fac_height);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.toolbar1), sebie->view.entry_selection_fac_height);
 #elif GTK_CHECK_VERSION(3,0,0)
@@ -223,10 +286,18 @@ init_sebie_view(struct sebie_s *sebie)
                                 NULL, NULL, NULL);
   gtk_label_set_use_underline (GTK_LABEL (((GtkToolbarChild*) (g_list_last (GTK_TOOLBAR (sebie->view.toolbar1)->children)->data))->label), TRUE);
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (GTK_WIDGET(sebie->view.button_fac_swap), TRUE);
+#else
   gtk_widget_show (GTK_WIDGET(sebie->view.button_fac_swap));
+#endif
 
   sebie->view.label_selection_fac = gtk_label_new (_("label1"));
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.label_selection_fac, TRUE);
+#else
   gtk_widget_show (sebie->view.label_selection_fac);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.toolbar1), sebie->view.label_selection_fac);
 #elif GTK_CHECK_VERSION(3,0,0)
@@ -240,7 +311,11 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_fac), GTK_JUSTIFY_LEFT);
 
   sebie->view.label_selection_gamma = gtk_label_new (_(" gamma:"));
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.label_selection_gamma, TRUE);
+#else
   gtk_widget_show (sebie->view.label_selection_gamma);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.toolbar1), sebie->view.label_selection_gamma);
 #elif GTK_CHECK_VERSION(3,0,0)
@@ -254,7 +329,11 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_gamma), GTK_JUSTIFY_LEFT);
 
   sebie->view.entry_selection_gamma = gtk_spin_button_new_with_range(0.1, 3.0, 0.1);
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.entry_selection_gamma, TRUE);
+#else
   gtk_widget_show (sebie->view.entry_selection_gamma);
+#endif
 
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.toolbar1), sebie->view.entry_selection_gamma);
@@ -288,7 +367,11 @@ init_sebie_view(struct sebie_s *sebie)
                                                              NULL, NULL, NULL);
   gtk_label_set_use_underline (GTK_LABEL (((GtkToolbarChild*) (g_list_last (GTK_TOOLBAR (sebie->view.toolbar1)->children)->data))->label), TRUE);
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (GTK_WIDGET(sebie->view.button_grayscale), TRUE);
+#else
   gtk_widget_show (GTK_WIDGET(sebie->view.button_grayscale));
+#endif
 
 #if !GTK_CHECK_VERSION(3,0,0)
   sebie->view.hpaned1 = gtk_hpaned_new ();
@@ -301,7 +384,11 @@ init_sebie_view(struct sebie_s *sebie)
 #else
   sebie->view.vbox2 = gtk_vbox_new (FALSE, 0);
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.vbox2, TRUE);
+#else
   gtk_widget_show (sebie->view.vbox2);
+#endif
 #if GTK_CHECK_VERSION(3,0,0)
   gtk_grid_attach (GTK_GRID (sebie->view.grid1), sebie->view.vbox2, 0, 1, 1, 1);
   gtk_widget_set_size_request (sebie->view.vbox2, 150, -1);
@@ -311,7 +398,11 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_paned_pack1 (GTK_PANED (sebie->view.hpaned1), sebie->view.vbox2, FALSE, TRUE);
 #endif
   sebie->view.label_input_path = gtk_label_new ("Path:");
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.label_input_path, TRUE);
+#else
   gtk_widget_show (sebie->view.label_input_path);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.label_input_path);
 #else
@@ -319,7 +410,11 @@ init_sebie_view(struct sebie_s *sebie)
 #endif
 
   sebie->view.entry_input_path = gtk_entry_new ();
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.entry_input_path, TRUE);
+#else
   gtk_widget_show (sebie->view.entry_input_path);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.entry_input_path);
 #else
@@ -327,7 +422,11 @@ init_sebie_view(struct sebie_s *sebie)
 #endif
 
   sebie->view.label_input_regex = gtk_label_new ("Regex:");
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.label_input_regex, TRUE);
+#else
   gtk_widget_show (sebie->view.label_input_regex);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.label_input_regex);
 #else
@@ -335,7 +434,11 @@ init_sebie_view(struct sebie_s *sebie)
 #endif
 
   sebie->view.entry_input_regex = gtk_entry_new ();
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.entry_input_regex, TRUE);
+#else
   gtk_widget_show (sebie->view.entry_input_regex);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.entry_input_regex);
 #else
@@ -343,7 +446,11 @@ init_sebie_view(struct sebie_s *sebie)
 #endif
 
   sebie->view.label_output_format = gtk_label_new ("Output Format:");
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.label_output_format, TRUE);
+#else
   gtk_widget_show (sebie->view.label_output_format);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.label_output_format);
 #else
@@ -351,7 +458,11 @@ init_sebie_view(struct sebie_s *sebie)
 #endif
 
   sebie->view.entry_output_format = gtk_entry_new ();
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.entry_output_format, TRUE);
+#else
   gtk_widget_show (sebie->view.entry_output_format);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.entry_output_format);
 #else
@@ -359,7 +470,11 @@ init_sebie_view(struct sebie_s *sebie)
 #endif
 
   sebie->view.label_output_file = gtk_label_new ("Output:");
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.label_output_file, TRUE);
+#else
   gtk_widget_show (sebie->view.label_output_file);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.label_output_file);
 #else
@@ -367,13 +482,23 @@ init_sebie_view(struct sebie_s *sebie)
 #endif
 
   sebie->view.entry_output_file = gtk_entry_new ();
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.entry_output_file, TRUE);
+#else
   gtk_widget_show (sebie->view.entry_output_file);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.entry_output_file);
 #else
   gtk_box_pack_start (GTK_BOX (sebie->view.vbox2), sebie->view.entry_output_file, FALSE, FALSE, 0);
 #endif
 
+#if GTK_CHECK_VERSION(4,10,0)
+  sebie->view.label_file_list = gtk_label_new ("InputFile:");
+  gtk_widget_set_visible (sebie->view.label_file_list, TRUE);
+  gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.label_file_list);
+#endif
+
 #if GTK_CHECK_VERSION(4,0,0)
   sebie->view.scrolledwindow1 = gtk_scrolled_window_new ();
   gtk_widget_set_vexpand(sebie->view.scrolledwindow1, TRUE);
@@ -381,30 +506,50 @@ init_sebie_view(struct sebie_s *sebie)
 #else
   sebie->view.scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
 #endif
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.scrolledwindow1, TRUE);
+#else
   gtk_widget_show (sebie->view.scrolledwindow1);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_box_append( GTK_BOX(sebie->view.vbox2), sebie->view.scrolledwindow1);
 #else
   gtk_box_pack_start (GTK_BOX (sebie->view.vbox2), sebie->view.scrolledwindow1, TRUE, TRUE, 0);
 #endif
 
+#if GTK_CHECK_VERSION(4,10,0)
+  sebie->view.treeview_file_list_factory = gtk_signal_list_item_factory_new ();
+  g_signal_connect (sebie->view.treeview_file_list_factory, "setup", G_CALLBACK (file_list_setup_cb), NULL);
+  g_signal_connect (sebie->view.treeview_file_list_factory, "bind", G_CALLBACK (file_list_bind_cb), NULL);
+  sebie->view.treeview_file_list = gtk_list_view_new (GTK_SELECTION_MODEL (sebie->model.file_list_selection), sebie->view.treeview_file_list_factory);
+  gtk_widget_set_visible (sebie->view.treeview_file_list, TRUE);
+#else
   sebie->view.treeview_file_list = gtk_tree_view_new ();
   gtk_tree_view_set_model(GTK_TREE_VIEW(sebie->view.treeview_file_list), GTK_TREE_MODEL(sebie->model.file_list));
 
   gtk_widget_show (sebie->view.treeview_file_list);
+#endif
 #if GTK_CHECK_VERSION(4,0,0)
   gtk_scrolled_window_set_child( GTK_SCROLLED_WINDOW (sebie->view.scrolledwindow1), sebie->view.treeview_file_list);
 #else
   gtk_container_add (GTK_CONTAINER (sebie->view.scrolledwindow1), sebie->view.treeview_file_list);
 #endif
+
+#if !GTK_CHECK_VERSION(4,10,0)
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("InputFile", renderer, "text", 0, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(sebie->view.treeview_file_list), column);
+#endif
 
   sebie->view.drawingarea1 = gtk_drawing_area_new ();
+#if GTK_CHECK_VERSION(4,10,0)
+  gtk_widget_set_visible (sebie->view.drawingarea1, TRUE);
+#else
   gtk_widget_show (sebie->view.drawingarea1);
+#endif
+
 #if GTK_CHECK_VERSION(3,0,0)
   gtk_grid_attach (GTK_GRID (sebie->view.grid1), sebie->view.drawingarea1, 1, 1, 1, 1);
   gtk_widget_set_hexpand(sebie->view.drawingarea1, TRUE);
@@ -418,9 +563,15 @@ init_sebie_view(struct sebie_s *sebie)
                               sebie->model.window1_width,
                               sebie->model.window1_height);
 
+#if GTK_CHECK_VERSION(4,10,0)
+  sebie->view.statusbar1 = gtk_label_new ("");
+  gtk_widget_set_halign (sebie->view.statusbar1, GTK_ALIGN_START);
+  gtk_widget_set_visible (sebie->view.statusbar1, TRUE);
+#else
   sebie->view.statusbar1 = gtk_statusbar_new ();
   gtk_widget_show (sebie->view.statusbar1);
   sebie->view.statusbar1_context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(sebie->view.statusbar1), "SomeContext");
+#endif
 #if GTK_CHECK_VERSION(3,0,0)
   gtk_grid_attach (GTK_GRID (sebie->view.grid1), sebie->view.statusbar1, 0, 2, 2, 1);
   gtk_widget_set_hexpand(sebie->view.statusbar1, TRUE);
@@ -428,11 +579,17 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_box_pack_start (GTK_BOX (sebie->view.vbox1), sebie->view.statusbar1, FALSE, FALSE, 0);
 #endif
 
+#if GTK_CHECK_VERSION(4,10,0)
+  g_signal_connect(G_OBJECT(sebie->model.file_list_selection), "selection-changed",
+                   G_CALLBACK(on_file_list_single_selection_changed),
+                   sebie);
+#else
   GtkTreeSelection *select = gtk_tree_view_get_selection(GTK_TREE_VIEW(sebie->view.treeview_file_list));
   gtk_tree_selection_set_mode(select, GTK_SELECTION_SINGLE);
   g_signal_connect(G_OBJECT(select), "changed",
                    G_CALLBACK(on_treeview_file_list_changed),
                    sebie);
+#endif
   g_signal_connect ((gpointer) sebie->view.entry_input_path, "changed",
                     G_CALLBACK (on_entry_input_path_changed),
                     sebie);
@@ -549,6 +706,9 @@ init_sebie_view(struct sebie_s *sebie)
   GLADE_HOOKUP_OBJECT (sebie->view.window1, sebie->view.vbox2, "vbox2");
   GLADE_HOOKUP_OBJECT (sebie->view.window1, sebie->view.entry_input_path, "entry_input_path");
   GLADE_HOOKUP_OBJECT (sebie->view.window1, sebie->view.entry_output_file, "entry_output_file");
+#if GTK_CHECK_VERSION(4,10,0)
+  GLADE_HOOKUP_OBJECT (sebie->view.window1, sebie->view.label_file_list, "label_file_list");
+#endif
   GLADE_HOOKUP_OBJECT (sebie->view.window1, sebie->view.scrolledwindow1, "scrolledwindow1");
   GLADE_HOOKUP_OBJECT (sebie->view.window1, sebie->view.treeview_file_list, "treeview_file_list");
   GLADE_HOOKUP_OBJECT (sebie->view.window1, sebie->view.drawingarea1, "drawingarea1");
